@@ -14,20 +14,7 @@ from oead.byml import Hash, Array
 from typing import List, Tuple
 from zlib import crc32
 
-
-IS_ONE_TRIGGER_NAMES = [
-    "Clear_",
-    "Open_",
-]
-RESET_TYPE_ZERO_NAMES = [
-    "Clear_",
-    "Open_",
-    "Location_",
-    "DgnObj_EntranceTerminal",
-]
-BOOL_CATEGORY_ONE_NAMES = [
-    "Clear_",
-]
+from . import overrides
 
 
 class BFUFlag:
@@ -149,12 +136,11 @@ class BFUFlag:
         Only valid for S32Flag and BoolFlag."""
 
     def use_name_to_override_params(self) -> None:
-        for substr in IS_ONE_TRIGGER_NAMES:
-            if substr in self._data_name:
-                self._is_one_trigger = True
-        for substr in RESET_TYPE_ZERO_NAMES:
-            if substr in self._data_name:
-                self._reset_type = 0
+        OVERRIDES = overrides["STANDARD_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class BoolFlag(BFUFlag):
@@ -218,9 +204,11 @@ class BoolFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(BoolFlag, self).use_name_to_override_params()
-        for substr in BOOL_CATEGORY_ONE_NAMES:
-            if substr in self._data_name:
-                self._category = 1
+        OVERRIDES = overrides["BOOL_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class BoolArrayFlag(BFUFlag):
@@ -280,6 +268,11 @@ class BoolArrayFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(BoolArrayFlag, self).use_name_to_override_params()
+        OVERRIDES = overrides["BOOL_ARRAY_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class S32Flag(BFUFlag):
@@ -337,6 +330,11 @@ class S32Flag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(S32Flag, self).use_name_to_override_params()
+        OVERRIDES = overrides["S32_OVERRRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class S32ArrayFlag(BFUFlag):
@@ -396,6 +394,11 @@ class S32ArrayFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(S32ArrayFlag, self).use_name_to_override_params()
+        OVERRIDES = overrides["S32_ARRAY_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class F32Flag(BFUFlag):
@@ -451,6 +454,11 @@ class F32Flag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(F32Flag, self).use_name_to_override_params()
+        OVERRIDES = overrides["F32_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class F32ArrayFlag(BFUFlag):
@@ -510,6 +518,11 @@ class F32ArrayFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(F32ArrayFlag, self).use_name_to_override_params()
+        OVERRIDES = overrides["F32_ARRAY_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class StringFlag(BFUFlag):
@@ -562,6 +575,11 @@ class StringFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(StringFlag, self).use_name_to_override_params()
+        OVERRIDES = overrides["STRING_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class String32Flag(StringFlag):
@@ -659,6 +677,11 @@ class StringArrayFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(StringArrayFlag, self).use_name_to_override_params()
+        OVERRIDES = overrides["STRING_ARRAY_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class String64ArrayFlag(StringArrayFlag):
@@ -767,6 +790,11 @@ class Vec2Flag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(Vec2Flag, self).use_name_to_override_params()
+        OVERRIDES = overrides["VEC2_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class Vec2ArrayFlag(BFUFlag):
@@ -845,6 +873,11 @@ class Vec2ArrayFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(Vec2ArrayFlag, self).use_name_to_override_params()
+        OVERRIDES = overrides["VEC2_ARRAY_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class Vec3Flag(BFUFlag):
@@ -930,6 +963,11 @@ class Vec3Flag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(Vec3Flag, self).use_name_to_override_params()
+        OVERRIDES = overrides["VEC3_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class Vec3ArrayFlag(BFUFlag):
@@ -1019,6 +1057,11 @@ class Vec3ArrayFlag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(Vec3ArrayFlag, self).use_name_to_override_params()
+        OVERRIDES = overrides["VEC3_ARRAY_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
 
 
 class Vec4Flag(BFUFlag):
@@ -1110,3 +1153,9 @@ class Vec4Flag(BFUFlag):
 
     def use_name_to_override_params(self) -> None:
         super(Vec4Flag, self).use_name_to_override_params()
+        OVERRIDES = overrides["VEC4_OVERRIDES"]
+        for override in OVERRIDES:
+            for substr, value in override.items():
+                if substr in self._data_name:
+                    self._is_event_associated = value
+
